#
# spec file for package pdfmod
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pdfmod
Version:        0.9.1
Release:        lp150.1.25
Summary:        PDF Modifier
License:        GPL-2.0+
Group:          Productivity/Publishing/PDF
Url:            http://live.gnome.org/PdfMod
Source:         %{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM pdfmod-mono-2.10.patch bgo644516  dimstar@opensuse.org -- Fix build with recent mono, taken from git
Patch0:         pdfmod-mono-2.10.patch
# PATCH-FIX-UPSTREAM pdfmod-dotnet4.patch dimstar@opensuse.org -- Build for .Net 4.0 target
Patch1:         pdfmod-dotnet4.patch
# PATCH-FEATURE-UPSTREAM https://bugzilla.gnome.org/show_bug.cgi?id=736860
Source1:        pdfmod.appdata.xml
BuildRequires:  gconf-sharp2
BuildRequires:  glib-sharp2
BuildRequires:  mono(gmime-sharp)
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  gtk-sharp2
BuildRequires:  gtk-sharp2-gapi
BuildRequires:  hyena >= 0.3
BuildRequires:  intltool
BuildRequires:  mono-basic
BuildRequires:  mono-data-sqlite
BuildRequires:  mono-devel
BuildRequires:  mono-nunit
BuildRequires:  ndesk-dbus
BuildRequires:  ndesk-dbus-glib-devel
# To be able to automatically adjust the lib name in the dll map and get proper requires for it.
BuildRequires:  libpoppler-glib-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
Requires:       gtk-sharp2
# Require the libpoppler-glib package we used at build time.
Requires:       mono
Requires:       mono-core
Requires:       %(rpm -qa libpoppler-glib[0-9]* --qf "%%{name}")
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PDF Mod is a simple tool for modifying your PDFs: moving, removing,
extracting, and rotating pages.

%lang_package
%prep
%setup -q
translation-update-upstream
%patch0 -p1
%patch1 -p1
# Adjust poppler-sharp.dll.config -> It needs to point to the right library. Fail if we need to touch this manually.
LIBPOPPLER=$(readelf %{_libdir}/libpoppler-glib.so -a | grep "SONAME" | grep -P -o "\[.*\].*" | tr -d "[]")
grep "libpoppler-glib.so.4" lib/poppler-sharp/poppler-sharp/poppler-sharp.dll.config
sed -i "s:libpoppler-glib.so.4:$LIBPOPPLER:" lib/poppler-sharp/poppler-sharp/poppler-sharp.dll.config

%build
%configure
%{__make} %{?_smp_mflags}

%install
%makeinstall
%suse_update_desktop_file pdfmod Utility DesktopUtility
%find_lang %{name} %{?no_lang_C}
install -Dm0644 %{S:1} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%icon_theme_cache_post
%endif

%if 0%{?suse_version} > 1130
%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%defattr(-, root, root)
%doc AUTHORS NEWS README COPYING
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang

%changelog
* Thu Sep  7 2017 zaitor@opensuse.org
- Replace gmime-sharp with mono(gmime-sharp) BuildRequires: Fix
  build via the new compat package.
* Sat Oct  8 2016 mailaender@opensuse.org
- Add appdata.xml for https://en.opensuse.org/openSUSE:AppStore
* Tue Mar  8 2016 dimstar@opensuse.org
- Drop tango-icon-theme BuildRequires: not needed.
* Tue Jan 29 2013 dimstar@opensuse.org
- Add pdfmod-dotnet4.patch: Build for .Net 4.0 target.
* Sun Feb  5 2012 dimstar@opensuse.org
- Replace gmime-2_4-sharp BuildRequires with gmime-sharp: we now
  build against gmime 2.6.
* Sat Apr 30 2011 dimstar@opensuse.org
- Update to version 0.9.1:
  + Enhancements:
  - bgo#630012: Make removing many pages much faster
  + Bugs Fixed:
  - bgo#631456: Fix being able to load files with : in their path
  - Fix build on Mono 2.8
  - bgo#633125: Don't crash if unable to save
  - bgo#638852: Fix poppler-sharp.dll.config for NetBSD
  - Fix scrolling the view while dragging
  - bgo#642379: Don't crash if Outlines point to null
  - bgo#597215: Fix issue with saving landscape pages
  - bgo#631889: Fix crash on page click due to ExportImagesAction
  - bgo#633123: Fix crash if Catalog.Outlines is PdfNull
- Drop pdfmod-mono-2.8.patch: fixed upstream.
- Add pdfmod-mono-2.10.patch: fix build with Mono 2.10.
- Drop pdfmod-poppler-soname.patch and replace it with more logic:
  + Add libpoppler-glib-devel BuildRequires
  + Find the soname from libdir/libpoppler-glib.so and sed it into
    poppler-sharp.dll.config
- Replace the suse_version-based Requires on libpoppler-glib* with
  an automatically detected libpoppler-glib* that is used at build
  time.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Add missing Recommends for lang subpackage.
  english documentation is not there anymore.
* Wed Dec  8 2010 vuntz@opensuse.org
- Add pdfmod-mono-2.8.patch to fix build with mono 2.8.
* Tue Oct 12 2010 vuntz@opensuse.org
- Add pdfmod-poppler-soname.patch to use the right soname of
  libpoppler-glib on Factory/11.4.
- Require libpoppler-glib5 on Factory/11.4.
- Enable parallel build.
* Tue Sep 28 2010 gburt@suse.de
- Version 0.9.0
  + Enhancements:
  - Bookmarks support (bgo#627747)
  - Make Export Images a page action
  - Add zoom slider/buttons in bottom-right (bgo#614378,
    bgo#628437)
  + Bugs fixed:
  - Allow compiling with external poppler-sharp
  - Fix double-width page icon rendering (bgo#590744)
  - Make SaveAs not require unsaved changes (bgo#628449)
  - Fix crash with export images by escaping output path
  - Better handling of files dropped from nautilus
  - Avoid XDG-related crash in file chooser (bgo#619073)
  - Mark missing string as translatable (bgo#618596)
  - Escape directory and filenames properly before making them
    (bgo#606432)
  - Fix page tooltip logic
  + Updated translations.
* Sun Aug 22 2010 dimstar@opensuse.org
- Switch to gmime 2.4: BuildRequire gmime-2_4-sharp instead of
  gmime-sharp.
* Thu Aug 12 2010 vuntz@opensuse.org
- Remove unneeded BuildRequires: autoconf, automake, docbook_4,
  libtool, make, perl-XML-Parser, pkgconfig, scrollkeeper.
* Fri May  7 2010 gburt@suse.de
- Version 0.8.3 - bug fix only release
  + Release 0.8.2 should have required hyena 0.3
- BuildRequire hyena > 0.3 as a consequence.
* Fri May  7 2010 gburt@suse.de
- Version 0.8.2 - bug fix only release
  + Use the stock Dnd icons instead of thumbnails
  + Add Documents and Download dirs to the shortcuts list in
    chooser dialogs
  + Fix a crash when the default RegionInfo is null (bgo#596912)
  + Catch exceptions when inserting doc (bgo#614009)
  + Raise Document.Changed after Save so '*' in Title goes away
  + Fix issue with remembering last directory
* Wed Mar 24 2010 gburt@suse.de
- Version 0.8.1 - bug fix only release
  + Fix InvalidCastException crash when opening some documents
  + Remove gnome-sharp dep
  + Several new and updated translations
* Thu Nov 12 2009 gburt@suse.de
- Version 0.8
  + Add * to beginning of window title when unsaved
  + Can select more than one file in Open dialog
  + shift-ctrl-z now also works for Redo
  + Online docs now hosted on library.gnome.org
  + Add Invert Selection action
  + Launching with relative filepaths in args work
  + Updates to 12 translations, including 4 new ones
* Wed Sep  9 2009 gburt@suse.de
- Version 0.7
  + View Fullscreen option
  + User docs translated into ca
  + Build fixes for *bsd
  + Update recent files list after opening a document
  + libdir expansion issue fixed in Hyena, depend on 0.2
* Tue Aug 18 2009 gburt@suse.de
- Version 0.6
* Fri Aug  7 2009 gburt@suse.de
- Version 0.5
* Tue Aug  4 2009 gburt@suse.de
- Version 0.4
* Mon Jul 27 2009 gburt@suse.de
- Version 0.3
* Fri Jul 24 2009 gburt@suse.de
- Version 0.2 (bundling Mono.Data.Sqlite)
* Fri Jul 24 2009 gburt@suse.de
- Initial version (0.1)
